cli

package
v0.6.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 24, 2021 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildArborescence

func BuildArborescence()

BuildArborescence will build the final Arborescence

func CheckArguments

func CheckArguments()

CheckArguments will check the arguments of the CLI

func CheckConfigurationFolder

func CheckConfigurationFolder()

CheckConfigurationFolder Check is the configuration folder is set before using the CLI

func Cli

func Cli()

Cli is the cli function which will handle all the cli calls

func Init

func Init()

Init initialize the cli flags

func Interactive

func Interactive()

Interactive handles Interactive mode

Types

This section is empty.

Jump to